@@ -72,7 +72,7 @@ class DaskGatewaySlurmConfig(sinfo.SInfoTable):
         return
 
 
-class PClusterConfig(SlurmClusterConfig)
+class PClusterConfig(SlurmClusterConfig):
     """Dask cluster configuration options when running on SLURM"""
     partition = Unicode("", help="The partition to submit jobs to.", config=True)
     qos = Unicode("", help="QOS string associated with each job.", config=True)
@@ -83,7 +83,7 @@ class PClusterConfig(SlurmClusterConfig)
 class PClusterBackend(SlurmBackend):
 
     cluster_config_class = Type(
-        "aws_pcluster_dask_gateway.aws_pcluster_dask_gateway.PCLusterConfig",
+        "aws_pcluster_dask_gateway.aws_pcluster_dask_gateway.PClusterConfig",
         klass="dask_gateway_server.backends.base.ClusterConfig",
         help="The cluster config class to use",
         config=True,
